# AutoRA Core

`autora-core` is the core python module for [`autora`](https://autoresearch.github.io/autora/) 
(<b>Auto</b>mated <b>R</b>esearch <b>A</b>ssistant), an open-source framework for 
automating multiple stages of the empirical research process, including model discovery, experimental design, data 
collection, and documentation for open science.

The primary purpose of this module is to provide utilities for: 
- describing experiments, 
- running experimentalist pipelines,
- running cyclical experiments

See the tutorials and user guide at [`autora`](https://autoresearch.github.io/autora/) to get started.
